@@ -2,7 +2,7 @@ from django import template
 from django.contrib.humanize.templatetags.humanize import intcomma
 from django.core.exceptions import FieldDoesNotExist, ImproperlyConfigured
 from django.db.models import Manager, QuerySet
-from django.db.models.fields.files import ImageFieldFile
+from django.db.models.fields.files import FieldFile, ImageFieldFile
 from django.template import defaultfilters
 from django.urls import NoReverseMatch, reverse
 from django.utils.safestring import mark_safe
@@ -52,7 +52,11 @@ def sidebar_menu(context):
                         active,
                     )
                 )
-        sidebar.append((group_label, sections_data))
+
+        # If the group is empty skip it
+        if sections_data:
+            sidebar.append((group_label, sections_data))
+
     return {"sidebar": sidebar}
 
 
@@ -91,9 +95,19 @@ def getattr_filter(obj, name):
             else:
                 value = NO_IMAGE_VALUE
         if isinstance(value, Manager):
-            value = ", ".join([str(item) for item in value.all()]) or NONE_VALUE
+            if value.exists():
+                tags = '<div class="tags">'
+                for item in value.all():
+                    tags += f'<span class="tag">{str(item)}</span>'
+                value = mark_safe(tags + "</div>")
+            else:
+                value = NONE_VALUE
         if Point and isinstance(value, Point):
             value = f"{value.y},{value.x}"
+        if isinstance(value, FieldFile) and "csv" in value.name:
+            value = mark_safe(
+                f'<a href="{value.url}" type="text/csv" download>{value.name}</a>'
+            )
         return value
 
     if isinstance(name, tuple) and len(name) > 0:
